@@ -1,13 +1,3 @@
-"""
-Online chat room
-^^^^^^^^^^^^^^^^^^^
-Chat with everyone currently online
-
-:demo_host:`Demo </chat_room>`, `Source code <https://github.com/wang0618/PyWebIO/blob/dev/demos/chat_room.py>`_
-
-* Use coroutine-based sessions
-* Use `run_async() <pywebio.session.run_async>` to start background coroutine
-"""
 import asyncio
 
 from pywebio import start_server
@@ -21,6 +11,7 @@ MAX_MESSAGES_CNT = 10 ** 4
 chat_msgs = []  # 聊天记录 (name, msg)
 online_users = set()  # 在线用户
 
+
 def t(eng, chinese):
     """return English or Chinese text according to the user's browser language"""
     return chinese if 'zh' in session_info.user_language else eng
@@ -51,7 +42,7 @@ async def main():
     """
     global chat_msgs
 
-    put_markdown(t("## PyWebIO chat room\nWelcome to the chat room, you can chat with all the people currently online. You can open this page in multiple tabs of your browser to simulate a multi-user environment. This application uses less than 90 lines of code, the source code is [here](https://github.com/wang0618/PyWebIO/blob/dev/demos/chat_room.py)", "## PyWebIO聊天室\n欢迎来到聊天室，你可以和当前所有在线的人聊天。你可以在浏览器的多个标签页中打开本页面来测试聊天效果。本应用使用不到90行代码实现，源代码[链接](https://github.com/wang0618/PyWebIO/blob/dev/demos/chat_room.py)"), lstrip=True)
+    put_markdown(t("## PyWebIO chat room\nWelcome to the chat room, you can chat with all the people currently online. You can open this page in multiple tabs of your browser to simulate a multi-user environment. This application uses less than 90 lines of code, the source code is [here](https://github.com/wang0618/PyWebIO/blob/dev/demos/chat_room.py)", "## PyWebIO聊天室\n欢迎来到聊天室，你可以和当前所有在线的人聊天。你可以在浏览器的多个标签页中打开本页面来测试聊天效果。本应用使用不到90行代码实现，源代码[链接](https://github.com/wang0618/PyWebIO/blob/dev/demos/chat_room.py)"))
 
     msg_box = output()
     put_scrollable(msg_box, height=300, keep_bottom=True)
@@ -85,4 +76,4 @@ async def main():
 
 
 if __name__ == '__main__':
-    start_server(main, debug=True, port=8080, cdn=False)
+    start_server(main, debug=True, port=8080)
