@@ -1,10 +1,3 @@
-"""
-Markdown Live Preview
-^^^^^^^^^^^^^^^^^^^^^^^^^^
-The online markdown editor with live preview.
-
-:demo_host:`Demo </markdown_previewer>`, `Source code <https://github.com/wang0618/PyWebIO/blob/dev/demos/markdown_previewer.py>`_
-"""
 from pywebio import start_server
 
 from pywebio.output import *
@@ -19,8 +12,8 @@ def main():
     put_markdown("""# Markdown Live Preview
     The online markdown editor with live preview. The source code of this application is [here](https://github.com/wang0618/PyWebIO/blob/dev/demos/markdown_previewer.py).
     ## Write your Markdown
-    """, lstrip=True)
-    put_textarea('md_text', rows=18, code=True)
+    """)
+    put_textarea('md_text', rows=18, code={'mode': 'markdown'})
 
     put_buttons(['Download content'], lambda _: download('saved.md', pin.md_text.encode('utf8')), small=True)
 
@@ -32,4 +25,4 @@ def main():
 
 
 if __name__ == '__main__':
-    start_server(main, port=8080, debug=True, cdn=False)
+    start_server(main, port=8080, debug=True)
