@@ -16,7 +16,8 @@ import time
 from contextlib import contextmanager
 from typing import Dict
 
-from .utils import make_applications, render_page, deserialize_binary_event
+from .page import make_applications, render_page
+from .utils import deserialize_binary_event
 from ..session import CoroutineBasedSession, Session, ThreadBasedSession, register_session_implement_for_target
 from ..session.base import get_session_info_from_headers
 from ..utils import random_str, LRUDict, isgeneratorfunction, iscoroutinefunction, check_webio_js
@@ -310,8 +311,8 @@ class HttpHandler:
 
         if check_origin is None:
             self.check_origin = lambda origin: any(
-                fnmatch.fnmatch(origin, patten)
-                for patten in (allowed_origins or [])
+                fnmatch.fnmatch(origin, pattern)
+                for pattern in (allowed_origins or [])
             )
 
 
